"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MarkdownTranspiler = void 0;
const glob_1 = __importDefault(require("glob"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const file_1 = require("../utils/file");
class MarkdownTranspiler {
    constructor(options) {
        this.options = options;
    }
    startCompilation() {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => {
                // TODO keep file tree
                file_1.ensureDirectoryExistence(this.options.outputDir);
                glob_1.default(this.options.inputPattern, (error, inputPaths) => {
                    if (error)
                        return reject(error);
                    inputPaths.forEach((inputPath) => {
                        fs_1.default.readFile(inputPath, (error, markdownContent) => {
                            if (error)
                                return reject(error);
                            const parsedMarkdown = this.options.parser.toVue(markdownContent.toString());
                            const filename = this.getFileName(inputPath);
                            const vueFile = this.options.fileCreator.create(parsedMarkdown, this.options.parser.dependencies, filename);
                            const outputPath = path_1.default.join(this.options.outputDir, filename + '.vue');
                            fs_1.default.writeFile(outputPath, vueFile, (error) => {
                                if (error)
                                    return reject(error);
                                return resolve();
                            });
                        });
                    });
                });
            });
        });
    }
    getFileName(filepath) {
        return path_1.default.basename(filepath).split('.').shift();
    }
}
exports.MarkdownTranspiler = MarkdownTranspiler;
//# sourceMappingURL=markdown-transpiler.js.map